#ifndef kedusimpleentrydlg_included
#define kedusimpleentrydlg_included


#include "kedusimpleentrydlgForm.h"

class KEduSimpleEntryDlg : public KEduSimpleEntryDlgForm
{
    TQ_OBJECT
  

 public:





};

#endif // kedusimpleentrydlg_included
